#!/bin/bash
set -e

script_root="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

# where the result package will be stored
pkg_dest_dir="${script_root}"
pkg_name="snes9x"
pkg_version="1.55"
# mirrors listed here: http://www.snes9x.com/downloads.php
src_url="http://www.s9x-w32.de/dl/snes9x-1.55.tar.bz2"
src_tarball=${script_root}/$(basename "${src_url}")
build_dir="${script_root}/build"
build_deps=(
    'build-essential' 'checkinstall' 'pkg-config' 'libgtk2.0-dev' 'libxml2-dev' 'libxv-dev'
    'libsdl-dev' 'libsdl-dev' 'intltool' 'libminizip-dev'
)

COLOR_LCYAN='\033[1;36m'
COLOR_DEFAULT='\033[0m'
notify(){
    echo -e "${COLOR_LCYAN}$1${COLOR_DEFAULT}"
}

notify "Installing build dependencies..."
if ! sudo dpkg -s ${build_deps[@]}; then
    sudo apt install --yes ${build_deps[@]}
fi

notify "Downloading and extracting Snes9x source tarball..."
if [ ! -f "${src_tarball}" ]; then
    wget -O "${src_tarball}" "${src_url}"
fi
if [ ! -d "${build_dir}" ]; then
    mkdir -p "${build_dir}"
    tar xjf "${src_tarball}" -C "${build_dir}"
fi

notify "Configuring and building Snes9x sources..."
# Name of extracted from src tarball directory may vary in future. Change it if script fails here.
pushd "${build_dir}"/snes9x*/gtk
./configure && make

notify "Building debian package..."
# You can either add needed package metainformation as checkinstall arguments (see man checkinstall)
# or remove --default switch and then interactively specify needed info
# Also, you can create RPM and Slackware packages with checkinstall if needed
sudo checkinstall \
    --default --install=no --fstrans=yes \
    --pakdir "${pkg_dest_dir}" \
    --pkgname "${pkg_name}" \
    --pkgversion "${pkg_version}" \
    sudo make install
popd
